/* Copyright 1998-2017 Research Foundation State University of New York   */

/* This file is part of QUB Online.                                       */

/* QUB Online is free software; you can redistribute it and/or modify    */
/* it under the terms of the GNU General Public License as published by   */
/* the Free Software Foundation, either version 3 of the License, or      */
/* (at your option) any later version.                                    */

/* QUB Online is distributed in the hope that it will be useful,         */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of         */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          */
/* GNU General Public License for more details.                           */

/* You should have received a copy of the GNU General Public License,     */
/* named LICENSE.txt, in the QUB Online program directory.  If not, see  */
/* <http://www.gnu.org/licenses/>.                                        */

#ifndef QUBX_SKM_H
#define QUBX_SKM_H

#include "qubfast.h"
#include "qubx_model_storage.h"

#ifdef __cplusplus
extern "C" {
#endif

void* QUBFAST_API qubx_skm_session_create(double sampling, int maxN, qubx_model *model);
void QUBFAST_API qubx_skm_session_free(void *skm);
void QUBFAST_API qubx_skm_session_reset(void *skm, double dtMS);

// stateSeq can be NULL if you aren't interested
void QUBFAST_API qubx_skm_viterbi(void *skm, int n, float *data, int *stateSeq, double *ll);

int QUBFAST_API qubx_skm_iterate(void *skm, int n, float *data, int *stateSeq, int maxIter, int fixA, int *fixAmp, int *fixStd, double *ll);

int QUBFAST_API qubx_skm_Nstate(void *skm);
void QUBFAST_API qubx_skm_read_A(void *skm, double *A);
int QUBFAST_API qubx_skm_Nclass(void *skm);
void QUBFAST_API qubx_skm_read_amp(void *skm, double *amp, double *std);
int QUBFAST_API qubx_skm_Nevent(void *skm);
void QUBFAST_API qubx_skm_read_events(void *skm, int *classes, int *counts);

#ifdef __cplusplus
}
#endif

#endif
